imagedelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# imagedelegate

class `camelot.view.controls.delegates.imagedelegate.` `ImageDelegate`(parent=None, editable=True, **kwargs)
  `editor`

    alias of `ImageEditor`

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus